==> vite-plugin-proxy-0.4.1.tgz: package/test/frontends/frontend-uris.test.js <==
import { describe, it, expect, afterEach, jest } from '@jest/globals'
import path from 'path'
import vitePluginProxy from '../../src/index'
import { closeAllServers, createTestServer, createViteServer, getPort, http2Request, updateRequestManager } from '../util'

const PORT = getPort()
const SERVER_PORT = getPort()
const SERVER_PORT2 = getPort()
const __dirname = path.dirname(new URL(import.meta.url).pathname)

describe('frontend uris', function () {
  afterEach(async function () {
    await closeAllServers()
    updateRequestManager()
  })

  it('works', async function () {
    await createViteServer({
      root: __dirname,
      logLevel: 'silent',
      plugins: [vitePluginProxy({
        frontends: [{ target: `http://localhost:${SERVER_PORT}` }]
      })]
    }, PORT)

    const server = createTestServer()
    server.get('/other.js', (req, res) => {
      res.send('console.log("Hello world")')
    })
    await server.listen(SERVER_PORT)

    const { data: index } = await http2Request(`http://localhost:${PORT}/index.js`)
    expect(index).toEqual('window.test = \'foo\'\n')

    const { data: other } = await http2Request(`http://localhost:${PORT}/other.js`)
    expect(other).toEqual('console.log("Hello world")')
  })

  it('overrides remote files with local files', async function () {
    await createViteServer({
      root: __dirname,
      logLevel: 'silent',
      plugins: [vitePluginProxy({
        // this has to be thought of as a remote UI with the same files
        frontends: [{ target: `http://localhost:${SERVER_PORT}` }]
      })]
    }, PORT)

    const server = createTestServer()
    const mockCallback = jest.fn()
    server.get('/index.js', mockCallback)
    await server.listen(SERVER_PORT)

    const { data } = await http2Request(`http://localhost:${PORT}/index.js`)
    expect(data).toEqual('window.test = \'foo\'\n')

    // give it more time to make sure, the other servers would also been called
    await new Promise(resolve => setTimeout(resolve, 50))
    expect(mockCallback).not.toBeCalled()
  })

  it('caches the handler of a file and reuses it', async function () {
    await createViteServer({
      root: __dirname,
      logLevel: 'silent',
      plugins: [vitePluginProxy({
        frontends: [{ target: `http://localhost:${SERVER_PORT}` }, { target: `http://localhost:${SERVER_PORT2}` }]
      })]
    }, PORT)

    const server = createTestServer()
    const mockCallback = jest.fn((req, res, next) => next())
    server.get('/other.js', mockCallback)
    await server.listen(SERVER_PORT)

    const server2 = createTestServer()
    const mockCallback2 = jest.fn((req, res, next) => res.send('window.test = \'foo\'\n'))
    server2.get('/other.js', mockCallback2)
    await server2.listen(SERVER_PORT2)

    const { data } = await http2Request(`http://localhost:${PORT}/other.js`)
    expect(data).toEqual('window.test = \'foo\'\n')
    expect(mockCallback).toBeCalledTimes(1)
    expect(mockCallback2).toBeCalledTimes(1)

    const { data: data2 } = await http2Request(`http://localhost:${PORT}/other.js`)
    expect(data2).toEqual('window.test = \'foo\'\n')
    expect(mockCallback).toBeCalledTimes(1)
    expect(mockCallback2).toBeCalledTimes(2)
  })
})

==> vite-plugin-proxy-0.4.4.tgz: package/test/frontends/frontend-uris.test.js <==
import { describe, it, expect, afterEach, jest } from '@jest/globals'
import path from 'path'
import vitePluginProxy from '../../src/index'
import { closeAllServers, createTestServer, createViteServer, getPort, http2Request, updateRequestManager } from '../util'

const PORT = getPort()
const SERVER_PORT = getPort()
const SERVER_PORT2 = getPort()
const __dirname = path.dirname(new URL(import.meta.url).pathname)

describe('frontend uris', function () {
  afterEach(async function () {
    await closeAllServers()
    updateRequestManager()
  })

  it('works', async function () {
    await createViteServer({
      root: __dirname,
      logLevel: 'silent',
      plugins: [vitePluginProxy({
        frontends: [{ target: `http://localhost:${SERVER_PORT}` }]
      })]
    }, PORT)

    const server = createTestServer()
    server.get('/other.js', (req, res) => {
      res.send('console.log("Hello world")')
    })
    await server.listen(SERVER_PORT)

    const { data: index } = await http2Request(`http://127.0.0.1:${PORT}/index.js`)
    expect(index).toEqual('window.test = \'foo\'\n')

    const { data: other } = await http2Request(`http://127.0.0.1:${PORT}/other.js`)
    expect(other).toEqual('console.log("Hello world")')
  })

  it('overrides remote files with local files', async function () {
    await createViteServer({
      root: __dirname,
      logLevel: 'silent',
      plugins: [vitePluginProxy({
        // this has to be thought of as a remote UI with the same files
        frontends: [{ target: `http://localhost:${SERVER_PORT}` }]
      })]
    }, PORT)

    const server = createTestServer()
    const mockCallback = jest.fn()
    server.get('/index.js', mockCallback)
    await server.listen(SERVER_PORT)

    const { data } = await http2Request(`http://127.0.0.1:${PORT}/index.js`)
    expect(data).toEqual('window.test = \'foo\'\n')

    // give it more time to make sure, the other servers would also been called
    await new Promise(resolve => setTimeout(resolve, 50))
    expect(mockCallback).not.toBeCalled()
  })

  it('caches the handler of a file and reuses it', async function () {
    await createViteServer({
      root: __dirname,
      logLevel: 'silent',
      plugins: [vitePluginProxy({
        frontends: [{ target: `http://localhost:${SERVER_PORT}` }, { target: `http://localhost:${SERVER_PORT2}` }]
      })]
    }, PORT)

    const server = createTestServer()
    const mockCallback = jest.fn((req, res, next) => next())
    server.get('/other.js', mockCallback)
    await server.listen(SERVER_PORT)

    const server2 = createTestServer()
    const mockCallback2 = jest.fn((req, res, next) => res.send('window.test = \'foo\'\n'))
    server2.get('/other.js', mockCallback2)
    await server2.listen(SERVER_PORT2)

    const { data } = await http2Request(`http://127.0.0.1:${PORT}/other.js`)
    expect(data).toEqual('window.test = \'foo\'\n')
    expect(mockCallback).toBeCalledTimes(1)
    expect(mockCallback2).toBeCalledTimes(1)

    const { data: data2 } = await http2Request(`http://127.0.0.1:${PORT}/other.js`)
    expect(data2).toEqual('window.test = \'foo\'\n')
    expect(mockCallback).toBeCalledTimes(1)
    expect(mockCallback2).toBeCalledTimes(2)
  })
})
